package cd.casic.module.execute.docker.callback;

import com.github.dockerjava.api.async.ResultCallback;
import com.github.dockerjava.api.model.Frame;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.io.IOException;
import java.nio.charset.StandardCharsets;

/**
 * @description: 之前版本用的ExecStartResultCallback实现，现在废弃了，使用ResultCallback.Adapter<Frame>，未测试
 * @author: mianbin
 * @date: 2025/5/26 18:09
 * @version: 1.0
 */
@Slf4j
@RequiredArgsConstructor
public class LoggingCallback extends ResultCallback.Adapter<Frame> {

    private final String containerId;
    private final String execId;
    private StringBuffer buffer = new StringBuffer(1024);

    @Override
    public void onNext(Frame frame) {
        String streamType = frame.getStreamType().name();
        String message = new String(frame.getPayload(), StandardCharsets.UTF_8);
        if (streamType.equals("STDOUT")) {
            log.info("[容器: {}, ExecID: {}] 标准输出: {}", containerId, execId, message.trim());
        } else if (streamType.equals("STDERR")) {
            log.error("[容器: {}, ExecID: {}] 错误输出: {}", containerId, execId, message.trim());
        }
        buffer.append(message);
        super.onNext(frame);
    }

    @Override
    public void onError(Throwable throwable) {
        log.error("[容器: {}, ExecID: {}] 执行命令时出错: {}", containerId, execId, throwable.getMessage());
        super.onError(throwable);
    }

    @Override
    public void onComplete() {
        log.info("[容器: {}, ExecID: {}] 命令执行完毕", containerId, execId);
        super.onComplete();
    }

    @Override
    public void close() throws IOException {

        log.debug("[容器: {}, ExecID: {}] 回调已关闭", containerId, execId);
        super.close();
    }

}
